pub struct LlmClient { /* private fields */ }Expand description
The main client for interacting with LLM APIs.
The LlmClient struct provides a convenient way to make requests to LLM APIs using the
RequestBuilder. It internally uses the appropriate client implementation based on the
selected ClientLlm enum variant.
Implementations