pub enum AnthropicContentBlock {
Text {
text: String,
block_type: String,
},
ToolUse {
block_type: String,
id: String,
name: String,
input: Value,
},
}Expand description
Represents a block of content in the API response.
Variants
Text
Represents a text content block in the Anthropic API response.
Fields
ToolUse
Represents a tool use content block in the Anthropic API response. This is used when the model decides to use a tool.
Fields